@@ -1,5 +1,5 @@
 #define JULIUS_PRODUCTNAME ""
-#define JULIUS_VERSION "4.4.2.1"
+#define JULIUS_VERSION "4.5"
 #define JULIUS_SETUP "fast"
 #define JULIUS_HOSTINFO ""
 #define JULIUS_BUILD_INFO ""
@@ -15,3 +15,5 @@
 #define GRAPHOUT_DYNAMIC 1
 #define GRAPHOUT_SEARCH 1
 #define HAVE_STRCASECMP 1
+/* Define if you have libfvad under this dir and enable it */
+#define HAVE_LIBFVAD
